@@ -1,26 +1,15 @@
 # -*- coding: utf-8 -*-
+
 '''
 @author: Soizic Laguitton
+
+@organization: I2BM, Neurospin, Gif-sur-Yvette, France
+@organization: CATI, France
 @organization: U{IFR 49<http://www.ifr49.org>}
+
 @license: U{CeCILL version 2<http://www.cecill.info/licences/Licence_CeCILL_V2-en.html>}
 '''
 
-'''
-soma-workflow client classes
-
-The WorkflowController instances allow to submit, control and monitor jobs and
-workflows on local or remote resources where the WorkflowDatabaseServer runs.
-The contrustor takes a resource id, login and password as parameters and
-connects to the resource. One WorkflowController instance is connected to
-only one resource.
-
-The other classes (Workflow, Job, Group, FileTransfer and SharedResourcePath) are made to build the jobs, workflows, and file transfers
-objects to be used in the WorkflowController interface.
-
-Definitions:
-A Parallel job is a job requiring more than one node to run.
-DRMS: distributed resource management system
-'''
 
 #-------------------------------------------------------------------------------
 # Imports
@@ -46,7 +35,7 @@ import soma.workflow.connection as connection
 from soma.workflow.transfer import PortableRemoteTransfer, TransferSCP, TransferRsync, TransferMonitoring, TransferLocal
 import soma.workflow.constants as constants
 import soma.workflow.configuration as configuration
-from soma.workflow.errors import TransferError, SerializationError
+from soma.workflow.errors import TransferError, SerializationError, SomaWorkflowError
 
 
 #-------------------------------------------------------------------------------
@@ -123,7 +112,7 @@ class WorkflowController(object):
     self.scheduler_config = None
 
     mode = self.config.get_mode()
-    print  mode + " mode"
+    #print  mode + " mode"
 
     self._resource_id = resource_id
     
@@ -135,16 +124,7 @@ class WorkflowController(object):
       self._engine_proxy = self._connection.get_workflow_engine()
       self.engine_config_proxy = self._connection.get_configuration()
       self._transfer = TransferLocal(self._engine_proxy)
-      #self._transfer = PortableRemoteTransfer(self._engine_proxy)
-      #self._transfer = TransferSCP(self._engine_proxy,
-                                    #username=None,
-                                    #hostname=None)
-
-      #self._transfer = TransferRsync(self._engine_proxy,
-                                    #username=None,
-                                    #hostname=None)
       self._transfer_stdouterr = TransferLocal(self._engine_proxy)
-      #self._transfer = PortableRemoteTransfer(self._engine_proxy)
       
 
     # REMOTE MODE
@@ -153,8 +133,7 @@ class WorkflowController(object):
       sub_machine = submitting_machines[random.randint(0,
                                                     len(submitting_machines)-1)]
       cluster_address = self.config.get_cluster_address()
-      print 'cluster address: ' + cluster_address
-      print 'submission machine: ' + sub_machine
+      #print 'cluster address: ' + cluster_address + ' submission machine: ' + sub_machine
       self._connection = connection.RemoteConnection(login,
                                                     password,
                                                     cluster_address,
@@ -186,7 +165,6 @@ class WorkflowController(object):
       self.engine_config_proxy = self.config
       self._connection = None
       self._transfer = TransferLocal(self._engine_proxy)
-      #self._transfer = PortableRemoteTransfer(self._engine_proxy)
       self._transfer_stdouterr = TransferLocal(self._engine_proxy)
 
 
@@ -233,6 +211,11 @@ class WorkflowController(object):
     Raises *WorkflowError* or *JobError* if the workflow is not correct.
     '''
 
+    if self.engine_config_proxy.get_scheduler_type() == configuration.MPI_SCHEDULER:
+      raise SomaWorkflowError("The MPI scheduler is configured for this resource. "
+                              "Use soma.workflow.MPI_workflow_runner to submit a workflow using the MPI scheduler.") 
+
+
     #cProfile.runctx("wf_id = self._engine_proxy.submit_workflow(workflow, expiration_date, name, queue)", globals(), locals(), "/home/soizic/profile/profile_submit_workflow")
 
     wf_id = self._engine_proxy.submit_workflow(workflow,
@@ -244,6 +227,8 @@ class WorkflowController(object):
 
   def submit_job(self, job, queue=None):
     '''
+    **deprecated since version 2.4:** Use submit_workflow instead.
+
     Submits a job which is not part of a workflow.
     Returns a job identifier.
 
@@ -264,6 +249,10 @@ class WorkflowController(object):
 
     Raises *JobError* if the job is not correct.
     '''
+    print "The method submit_job is deprecated since version 2.4. Use submit_workflow instead."
+    if self.engine_config_proxy.get_scheduler_type() == configuration.MPI_SCHEDULER:
+      raise SomaWorkflowError("The MPI scheduler is configured for this resource. "
+                              "Use soma.workflow.MPI_workflow_runner to submit a workflow using the MPI scheduler.") 
 
     job_id = self._engine_proxy.submit_job(job, queue)
     return job_id
@@ -358,7 +347,7 @@ class WorkflowController(object):
     return self._engine_proxy.workflow_status(workflow_id)
 
 
-  def workflow_elements_status(self, workflow_id, group = None):
+  def workflow_elements_status(self, workflow_id):
     '''
     Gets back the status of all the workflow elements at once, minimizing the
     communication with the server and request to the database.
@@ -373,7 +362,7 @@ class WorkflowController(object):
     Raises *UnknownObjectError* if the workflow_id is not valid
     '''
     wf_status = self._engine_proxy.workflow_elements_status(workflow_id)
-     # special processing for transfer status:
+    # special processing for transfer status:
     new_transfer_status = []
     for engine_path, client_path, client_paths, status, transfer_type in wf_status[1]:
       progression = self._transfer_progression(status,
@@ -512,6 +501,10 @@ class WorkflowController(object):
 
     Raises *UnknownObjectError* if the workflow_id is not valid
     '''
+    if self.engine_config_proxy.get_scheduler_type() == configuration.MPI_SCHEDULER:
+      raise SomaWorkflowError("The MPI scheduler is configured for this resource. "
+                              "Use soma.workflow.MPI_workflow_runner to restart a workflow using the MPI scheduler.") 
+
     return self._engine_proxy.restart_workflow(workflow_id, queue)
 
 
@@ -551,6 +544,10 @@ class WorkflowController(object):
       if some jobs are possibly still running on the computing resource 
       despite the workflow was stopped.
     '''
+    if self.engine_config_proxy.get_scheduler_type() == configuration.MPI_SCHEDULER:
+      raise SomaWorkflowError("The MPI scheduler is configured for this resource. "
+                              "Kill the soma.workflow.MPI_workflow_runner job to stop the workflow.") 
+
 
     return self._engine_proxy.stop_workflow(workflow_id)
 
@@ -589,17 +586,23 @@ class WorkflowController(object):
 
   def kill_job(self, job_id ):
     '''
+    **deprecated since version 2.4:** Use stop_workflow instead.
+
     Kills a running job. The job will not be deleted from the system (the job
     identifier remains valid).
     Use the restart_job method to restart the job.
 
     Raises *UnknownObjectError* if the job_id is not valid
     '''
+    print "The method kill_job is deprecated since version 2.4. Use stop_workflow instead."
+
     self._engine_proxy.kill_job(job_id)
 
 
   def restart_job(self, job_id):
     '''
+    **deprecated since version 2.4:** Use restart_workflow instead.
+
     Restarts a job which status is constants.FAILED or constants.WARNING.
 
     * job_id *job identifier*
@@ -608,11 +611,14 @@ class WorkflowController(object):
 
     Raises *UnknownObjectError* if the job_id is not valid
     '''
+    print "The method restart_job is deprecated since version 2.4. Use submit_workflow instead."
     self._engine_proxy.restart_job(job_id)
 
 
   def delete_job(self, job_id, force=True):
     '''
+    **deprecated since version 2.4:** Use delete_workflow instead.
+
     Deletes a job which is not part of a workflow.
     The job_id will become invalid and can not be used anymore.
     The job is killed if it is running.
@@ -624,6 +630,7 @@ class WorkflowController(object):
       if some jobs are possibly still running on the computing resource despite
       the workflow doesn't exist.
     '''
+    print "The method delete_job is deprecated since version 2.4. Use delete_workflow instead."
 
     return self._engine_proxy.delete_job(job_id, force)
 
@@ -932,18 +939,18 @@ def _embedded_engine_and_server(config, local_scheduler_config=None):
   database_server = WorkflowDatabaseServer(config.get_database_file(),
                                            config.get_transfered_file_dir())
 
-  if config.get_scheduler_type() == 'drmaa':
+  if config.get_scheduler_type() == configuration.DRMAA_SCHEDULER:
     from soma.workflow.scheduler import Drmaa
-    print "scheduler type: drmaa"
+    #print "scheduler type: drmaa"
     scheduler = Drmaa(config.get_drmaa_implementation(),
                       config.get_parallel_job_config(),
                       configured_native_spec=config.get_native_specification())
 
-  elif config.get_scheduler_type() == 'local_basic':
+  elif config.get_scheduler_type() == configuration.LOCAL_SCHEDULER:
     from soma.workflow.scheduler import ConfiguredLocalScheduler
     if local_scheduler_config == None:
       local_scheduler_config = LocalSchedulerCfg()
-    print "scheduler type: basic, number of cpu: " + repr(local_scheduler_config.get_proc_nb())
+    #print "scheduler type: basic, number of cpu: " + repr(local_scheduler_config.get_proc_nb())
     scheduler = ConfiguredLocalScheduler(local_scheduler_config)
 
   workflow_engine = ConfiguredWorkflowEngine(database_server,
