@@ -1,10 +1,17 @@
 # -*- coding: utf-8 -*-
+
 '''
 @author: Soizic Laguitton
+
+@organization: I2BM, Neurospin, Gif-sur-Yvette, France
+@organization: CATI, France
 @organization: U{IFR 49<http://www.ifr49.org>}
+
 @license: U{CeCILL version 2<http://www.cecill.info/licences/Licence_CeCILL_V2-en.html>}
 '''
 
+
+
 #-------------------------------------------------------------------------------
 # Imports
 #-------------------------------------------------------------------------------
@@ -31,8 +38,10 @@ MODES = [LIGHT_MODE,
 
 LOCAL_SCHEDULER = 'local_basic'
 DRMAA_SCHEDULER = 'drmaa'
+MPI_SCHEDULER = 'mpi'
 SCHEDULER_TYPES = [LOCAL_SCHEDULER,
-                   DRMAA_SCHEDULER]
+                   DRMAA_SCHEDULER,
+                   MPI_SCHEDULER]
 
 # configuration variables ------------------------------------------------------
 
@@ -451,6 +460,10 @@ class Configuration(observer.Observable):
       self._mode = LIGHT_MODE
       return self._mode
     
+    if not self._config_parser.has_option(self._resource_id, CFG_SUBMITTING_MACHINES):
+       self._mode = LOCAL_MODE
+       return self._mode
+ 
     if not self._submitting_machines:
       self._submitting_machines = self.get_submitting_machines()
    
