@@ -3,25 +3,14 @@ from __future__ import with_statement
 
 '''
 @author: Soizic Laguitton
+
+@organization: I2BM, Neurospin, Gif-sur-Yvette, France
+@organization: CATI, France
 @organization: U{IFR 49<http://www.ifr49.org>}
+
 @license: U{CeCILL version 2<http://www.cecill.info/licences/Licence_CeCILL_V2-en.html>}
 '''
 
-''' 
-soma-workflow local and remote connections from client to computing resource.
-
-The RemoteConnection and LocalConnection instances should be created on the 
-client side. Their constructor creates a WorkflowEngine object on the 
-computing resource and setup the pyro communicaiton with it. The method
-getWorkflowEngine get back a pyro proxy of the remote WorkflowEngine object.
-The RemoteConnection and object contains a thead which signals to the 
-WorkflowEngine object at regular time interval that the client is still
-connected.
-
-requirements: Pyro and Paramiko must be installed on the remote machine.
-'''
-
-
 
 #-------------------------------------------------------------------------------
 # Imports
@@ -92,12 +81,12 @@ class RemoteConnection( object ):
     # run the workflow engine process and get back the    #
     # WorkflowEngine and ConnectionChecker URIs       #
     command = "python -m soma.workflow.start_workflow_engine %s %s %s" %(resource_id, pyro_objet_name, log) 
-    print "start engine command: " + command
+    print "start engine command: ssh %s@%s %s" %(login, cluster_address, command)
     try:
       client = paramiko.SSHClient()
       client.set_missing_host_key_policy(paramiko.AutoAddPolicy()) 
       client.load_system_host_keys()
-      client.connect(hostname = cluster_address, port=22, username=login, password=password)
+      client.connect(hostname=cluster_address, port=22, username=login, password=password)
       stdin, stdout, stderr = client.exec_command(command)
     except paramiko.AuthenticationException, e:
       raise ConnectionError("The authentification failed. %s" %(e))
@@ -176,15 +165,15 @@ class RemoteConnection( object ):
     configuration_uri = line.split()[1] 
     client.close()
     
-    print "workflow_engine_uri: " +  workflow_engine_uri
-    print "connection_checker_uri: " +  connection_checker_uri
-    print "configuration_uri: " + configuration_uri
+    #print "workflow_engine_uri: " +  workflow_engine_uri
+    #print "connection_checker_uri: " +  connection_checker_uri
+    #print "configuration_uri: " + configuration_uri
     engine_pyro_daemon_port = Pyro.core.processStringURI(workflow_engine_uri).port
-    print "Pyro object port: " + repr(engine_pyro_daemon_port)
+    #print "Pyro object port: " + repr(engine_pyro_daemon_port)
   
     # find an available port              #
     client_pyro_daemon_port = searchAvailablePort()
-    print "client pyro object port: " + repr(client_pyro_daemon_port)
+    #print "client pyro object port: " + repr(client_pyro_daemon_port)
 
     
     # tunnel creation                      #
@@ -202,9 +191,9 @@ class RemoteConnection( object ):
           key = paramiko.RSAKey.from_private_key_file(rsa_file_path)
         self.__transport.auth_publickey(login, key)
         #TBI DSA Key => see paramamiko/demos/demo.py for an example
-      print "tunnel creation " + repr(login) + "@" + repr(cluster_address)
-      print "   port: " + repr(client_pyro_daemon_port) + " host: " + \
-      repr(submitting_machine) + " host port: " + repr(engine_pyro_daemon_port) 
+      print "tunnel creation " + str(login) + "@" + cluster_address + \
+            "   port: " + repr(client_pyro_daemon_port) + " host: " + \
+            str(submitting_machine) + " host port: " + str(engine_pyro_daemon_port) 
 
       tunnel = Tunnel(client_pyro_daemon_port, submitting_machine, engine_pyro_daemon_port, self.__transport) 
       tunnel.start()
