@@ -1,9 +1,20 @@
 '''
 @author: Soizic Laguitton
+
+@organization: I2BM, Neurospin, Gif-sur-Yvette, France
+@organization: CATI, France
 @organization: U{IFR 49<http://www.ifr49.org>}
+
 @license: U{CeCILL version 2<http://www.cecill.info/licences/Licence_CeCILL_V2-en.html>}
 '''
 
+class SomaWorkflowError(Exception):
+  '''
+  Wrong usage of Soma-workflow.
+  '''
+  pass
+
+
 class ConfigurationError(Exception): 
   '''
   Raised when the configuration is not correct or when configuration
