@@ -2,10 +2,15 @@ from __future__ import with_statement
 
 '''
 @author: Soizic Laguitton
+
+@organization: I2BM, Neurospin, Gif-sur-Yvette, France
+@organization: CATI, France
 @organization: U{IFR 49<http://www.ifr49.org>}
+
 @license: U{CeCILL version 2<http://www.cecill.info/licences/Licence_CeCILL_V2-en.html>}
 '''
 
+
 import subprocess
 import threading
 import time
@@ -16,6 +21,7 @@ import signal
 import ctypes
 import atexit
 import os.path
+import socket
 
 import soma.workflow.constants as constants
 from soma.workflow.errors import DRMError
@@ -125,6 +131,8 @@ class Drmaa(Scheduler):
     except DrmaaError, e:
       self.logger.critical("Could not create the DRMAA session: %s" %e )
       raise DRMError("Could not create the DRMAA session: %s" %e )
+  
+    self.hostname = socket.gethostname()
 
     self._drmaa_implementation = drmaa_implementation
 
@@ -146,10 +154,10 @@ class Drmaa(Scheduler):
         self._drmaa.setCommand(jobTemplateId, "echo", [])
         self._drmaa.setAttribute(jobTemplateId, 
                                 "drmaa_output_path", 
-                                "[void]:" + os.path.join(self.tmp_file_path, "soma-workflow-empty-job-patch-torque.o"))
+                                "[%s]:%s" %(self.hostname, os.path.join(self.tmp_file_path, "soma-workflow-empty-job-patch-torque.o")))
         self._drmaa.setAttribute(jobTemplateId, 
                                 "drmaa_error_path", 
-                                "[void]:" + os.path.join(self.tmp_file_path, "soma-workflow-empty-job-patch-torque.e"))
+                                "[%s]:%s" %(self.hostname, os.path.join(self.tmp_file_path, "soma-workflow-empty-job-patch-torque.e")))
         self._drmaa.runJob(jobTemplateId)
       except DrmaaError, e:
         self.logger.critical("%s" %e)
@@ -198,6 +206,8 @@ class Drmaa(Scheduler):
     command = []
     job_command = job.plain_command()
     if self._drmaa_implementation == "PBS":
+      if job_command[0] == 'python':
+        job_command[0] = sys.executable
       for command_el in job_command:
         command_el = command_el.replace('"', '\\\"')
         command.append("\"" + command_el + "\"")
@@ -210,9 +220,6 @@ class Drmaa(Scheduler):
     stdout_file = job.plain_stdout()
     stderr_file = job.plain_stderr()
     stdin = job.plain_stdin()
-    job_env = []
-    for var_name in os.environ.keys():
-      job_env.append(var_name+"="+os.environ[var_name])
 
     try:
       drmaaJobId = self._drmaa.allocateJobTemplate()
@@ -221,7 +228,7 @@ class Drmaa(Scheduler):
  
       self._drmaa.setAttribute(drmaaJobId, 
                               "drmaa_output_path", 
-                              "[void]:" + stdout_file)
+                              "[%s]:%s" %(self.hostname, stdout_file))
  
       if job.join_stderrout:
         self._drmaa.setAttribute(drmaaJobId,
@@ -231,13 +238,13 @@ class Drmaa(Scheduler):
         if stderr_file:
           self._drmaa.setAttribute(drmaaJobId, 
                                   "drmaa_error_path", 
-                                  "[void]:" + stderr_file)
+                                  "[%s]:%s" %(self.hostname, stderr_file))
       
       if job.stdin:
         #self.logger.debug("stdin: " + repr(stdin))
         self._drmaa.setAttribute(drmaaJobId, 
                                 "drmaa_input_path", 
-                                "[void]:" + stdin)
+                                "[%s]:%s" %(self.hostname, stdin))
         
       working_directory = job.plain_working_directory()
       if working_directory:
@@ -268,8 +275,12 @@ class Drmaa(Scheduler):
         self._setDrmaaParallelJob(drmaaJobId, 
                                   parallel_config_name, 
                                   max_node_number)
-        
-      self._drmaa.setVectorAttribute(drmaaJobId, 'drmaa_v_env', job_env)
+       
+      if self._drmaa_implementation == "PBS": 
+        job_env = []
+        for var_name in os.environ.keys():
+          job_env.append(var_name+"="+os.environ[var_name])
+        self._drmaa.setVectorAttribute(drmaaJobId, 'drmaa_v_env', job_env)
 
       drmaaSubmittedJobId = self._drmaa.runJob(drmaaJobId)
       self._drmaa.deleteJobTemplate(drmaaJobId)
@@ -285,13 +296,6 @@ class Drmaa(Scheduler):
 
     return drmaaSubmittedJobId
   
-  #def process_str(self, value):
-    #if value and value.find(' ') != -1:
-      #result = "\'"+value+"\'"
-    #else: 
-      #result = value
-    #return result
-
 
   def get_job_status(self, scheduler_job_id):
     if self.is_sleeping: self.wake()
@@ -339,7 +343,6 @@ class Drmaa(Scheduler):
     for drmaa_attribute in constants.PARALLEL_DRMAA_ATTRIBUTES:
       value = self.parallel_job_submission_info.get(drmaa_attribute)
       if value: 
-        #value = value.format(config_name=cluster_specific_cfg_name, max_node=max_num_node)
         value = value.replace("{config_name}", cluster_specific_cfg_name)
         value = value.replace("{max_node}", repr(max_num_node))
         self._drmaa.setAttribute( drmaa_job_template_id, 
@@ -457,7 +460,7 @@ class LocalScheduler(Scheduler):
     with self._lock:
       self.stop_thread_loop = True
       self._loop.join()
-      print "Soma scheduler thread ended nicely."
+      #print "Soma scheduler thread ended nicely."
 
   def _iterate(self):
     # Nothing to do if the queue is empty and nothing is running
